# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`krb5`](#krb5): Kerberos 5 management and manipulation
* [`krb5::client`](#krb5--client): A client class that will connect with the given KDC
* [`krb5::config`](#krb5--config): **NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**  Basic configuration of the MIT Kerberos 
* [`krb5::config::default_settings`](#krb5--config--default_settings): Default System Settings
* [`krb5::install`](#krb5--install): Install the MIT Kerberos client
* [`krb5::kdc`](#krb5--kdc): The necessary structure to manage the Kerberos 5 KDC on a given system.
* [`krb5::kdc::auto_keytabs`](#krb5--kdc--auto_keytabs): Provides a mechanism for auto-generating keytabs on the KDC as well as provisioning those keytabs for distribution via Puppet if possible.
* [`krb5::kdc::config`](#krb5--kdc--config): Provides the necessary structure to manage the Kerberos 5 KDC on a given system.
* [`krb5::kdc::firewall`](#krb5--kdc--firewall): Set up the firewall for the KDC
* [`krb5::kdc::install`](#krb5--kdc--install): Install the krb5kdc packages
* [`krb5::kdc::selinux_hotfix`](#krb5--kdc--selinux_hotfix): This class provides a hotfix for a broken SELinux policy in EL7
* [`krb5::kdc::service`](#krb5--kdc--service): Manage the KRB5 services
* [`krb5::keytab`](#krb5--keytab): Distribute Kerberos keytabs in a sane manner

### Defined types

* [`krb5::kdc::realm`](#krb5--kdc--realm): Allows you to add a realm to the ``[realms]`` section of ``/var/kerberos/krb5kdc/kdc.conf``.
* [`krb5::setting`](#krb5--setting): Allows you to set individual configuration elements in ``/etc/krb5.conf``.
* [`krb5::setting::domain_realm`](#krb5--setting--domain_realm): Allows you to configure individual domain => realm mappings.
* [`krb5::setting::realm`](#krb5--setting--realm): Allows you to add a realm to the ``[realms]`` section of ``/etc/krb5.conf``.

### Resource types

* [`krb5_acl`](#krb5_acl): Manages krb5 kadmind ACL entries per kadmind(8). When removing an entry, you can specify a regex for the operation_target and all associated 
* [`krb5kdc_auto_keytabs`](#krb5kdc_auto_keytabs): Auto-generates principals and keytabs on a functional KDC and outputs the keytabs to a directory of the user's choosing.  Can optionally take

### Functions

* [`krb5::munge_conf_filename`](#krb5--munge_conf_filename): Returns a string that is safe to use as a filename for including in  krb5 configuration files.
* [`krb5::validate_time_duration`](#krb5--validate_time_duration): Validates that the passed string is a valid krb5 time duration per http://web.mit.edu/kerberos/krb5-1.13/doc/basic/date_format.html#duration.

## Classes

### <a name="krb5"></a>`krb5`

This base class installs everything necessary for basic KRB client use

We modify the default ``/etc/krb5.conf`` to use an include structure under
``/etc/krb5.conf.simp.d``. Each ``[subsection]`` is broken out into a
separate directory and all files in that directory are included.

#### Parameters

The following parameters are available in the `krb5` class:

* [`ldap`](#-krb5--ldap)
* [`firewall`](#-krb5--firewall)
* [`haveged`](#-krb5--haveged)
* [`enctypes`](#-krb5--enctypes)

##### <a name="-krb5--ldap"></a>`ldap`

Data type: `Boolean`

Configure the system to incorporate LDAP components

* This presently does **not** set up the LDAP back-end for KRB5

Default value: `simplib::lookup('simp_options::ldap', { 'default_value' => false })`

##### <a name="-krb5--firewall"></a>`firewall`

Data type: `Boolean`

Use the SIMP iptables module

Default value: `simplib::lookup('simp_options::firewall', { 'default_value' => false })`

##### <a name="-krb5--haveged"></a>`haveged`

Data type: `Boolean`

Use the SIMP haveged module

Default value: `simplib::lookup('simp_options::haveged', { 'default_value' => true })`

##### <a name="-krb5--enctypes"></a>`enctypes`

Data type: `Array[String]`

An Array of default permitted encryption types

Default value: `[ 'aes256-cts-hmac-sha1-96', 'aes128-cts-hmac-sha1-96' ]`

### <a name="krb5--client"></a>`krb5::client`

By default, this is set up to connect with the KDC that would be configured
if you use the default options.

#### Parameters

The following parameters are available in the `krb5::client` class:

* [`realms`](#-krb5--client--realms)

##### <a name="-krb5--client--realms"></a>`realms`

Data type:

```puppet
Hash[
    String,
    Struct[{
      admin_server  => Simplib::Host,
      Optional[kdc] => Simplib::Host
    }]
  ]
```

A Hash of Kerberos Realms that provide a Realm paired with an Admin Server
and a KDC

* If you specify nothing here, then the system will try to set up a client
  with the Puppet server as the KDC. This will fail if no server is
  specified.

Default value: `{}`

### <a name="krb5--config"></a>`krb5::config`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

Basic configuration of the MIT Kerberos client

#### Parameters

The following parameters are available in the `krb5::config` class:

* [`config_dir`](#-krb5--config--config_dir)
* [`default_realm`](#-krb5--config--default_realm)
* [`realm_domains`](#-krb5--config--realm_domains)
* [`dns_lookup_realm`](#-krb5--config--dns_lookup_realm)
* [`dns_lookup_kdc`](#-krb5--config--dns_lookup_kdc)
* [`renew_lifetime`](#-krb5--config--renew_lifetime)
* [`forwardable`](#-krb5--config--forwardable)
* [`clockskew`](#-krb5--config--clockskew)
* [`permitted_tgs_enctypes`](#-krb5--config--permitted_tgs_enctypes)
* [`permitted_tkt_enctypes`](#-krb5--config--permitted_tkt_enctypes)
* [`permitted_enctypes`](#-krb5--config--permitted_enctypes)
* [`puppet_exclusive_managed`](#-krb5--config--puppet_exclusive_managed)

##### <a name="-krb5--config--config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

The path to the Puppet managed config files.

Default value: `'/etc/krb5.conf.simp.d'`

##### <a name="-krb5--config--default_realm"></a>`default_realm`

Data type: `String`

Default realm to which to bind.

Default value: `inline_template('<%= @domain.upcase %>')`

##### <a name="-krb5--config--realm_domains"></a>`realm_domains`

Data type: `Array[String]`

Array of domains bound to the default realm set
in $default_realm.

Default value: `[ ".${facts['networking']['domain']}", $facts['networking']['domain'] ]`

##### <a name="-krb5--config--dns_lookup_realm"></a>`dns_lookup_realm`

Data type: `Boolean`

Use DNS TXT records to lookup the realm.

Default value: `false`

##### <a name="-krb5--config--dns_lookup_kdc"></a>`dns_lookup_kdc`

Data type: `Boolean`

Use DNS SRV records to lookup the KDC.

Default value: `true`

##### <a name="-krb5--config--renew_lifetime"></a>`renew_lifetime`

Data type: `String`

The default renewable lifetime for initial
tickets. Should be a valid krb5 Time Duration string.
@see http://web.mit.edu/kerberos/krb5-1.13/doc/basic/date_format.html#duration

Default value: `'7d'`

##### <a name="-krb5--config--forwardable"></a>`forwardable`

Data type: `Boolean`

Whether or not to make initial tickets
forwardable by default. This is needed for SSH GSSAPI.

Default value: `true`

##### <a name="-krb5--config--clockskew"></a>`clockskew`

Data type: `Integer[0]`

Max allowable amount of seconds of clockskew allowed
before assuming that a message is invalid.

Default value: `500`

##### <a name="-krb5--config--permitted_tgs_enctypes"></a>`permitted_tgs_enctypes`

Data type: `Array[String]`

Supported encryption types reported by the KDC.

Default value: `$krb5::enctypes`

##### <a name="-krb5--config--permitted_tkt_enctypes"></a>`permitted_tkt_enctypes`

Data type: `Array[String]`

Permitted client encryption types.

Default value: `$krb5::enctypes`

##### <a name="-krb5--config--permitted_enctypes"></a>`permitted_enctypes`

Data type: `Array[String]`

Permitted session key encryption types.

Default value: `$krb5::enctypes`

##### <a name="-krb5--config--puppet_exclusive_managed"></a>`puppet_exclusive_managed`

Data type: `Boolean`

Set to false to allow users to add files
to the /etc/krb5.conf.d directory manually.

Default value: `true`

### <a name="krb5--config--default_settings"></a>`krb5::config::default_settings`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

### <a name="krb5--install"></a>`krb5::install`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

#### Parameters

The following parameters are available in the `krb5::install` class:

* [`packages`](#-krb5--install--packages)
* [`ensure`](#-krb5--install--ensure)
* [`haveged`](#-krb5--install--haveged)

##### <a name="-krb5--install--packages"></a>`packages`

Data type: `Array[String[1]]`

The list of pakages to install

* Provided by module data

##### <a name="-krb5--install--ensure"></a>`ensure`

Data type: `String[1]`

The package state to ensure

* Compatible with the ``Package`` Resource ``ensure`` parameter can

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-krb5--install--haveged"></a>`haveged`

Data type: `Boolean`

Include ``haveged`` for entropy generation.

Default value: `$krb5::haveged`

### <a name="krb5--kdc"></a>`krb5::kdc`

The variables used here can be found in ``kdc.conf(5)``.

Any variable *not* covered here can be managed using file resources.

#### Examples

##### Add Your Own Custom Config Snippet

```puppet
class my_krb5kdc {
  include 'krb5::kdc'

  file { "${krb5::kdc::config_dir}/my_snippet__custom":
    content => "My Custom Content"
  }

  Class['krb5::kdc'] -> Class['my_krb5kdc']
  Class['my_krb5kdc'] ~> Class['krb5::kdc::service']
}
```

#### Parameters

The following parameters are available in the `krb5::kdc` class:

* [`trusted_nets`](#-krb5--kdc--trusted_nets)
* [`config_dir`](#-krb5--kdc--config_dir)
* [`ldap`](#-krb5--kdc--ldap)
* [`firewall`](#-krb5--kdc--firewall)
* [`haveged`](#-krb5--kdc--haveged)
* [`auto_initialize`](#-krb5--kdc--auto_initialize)
* [`auto_realm`](#-krb5--kdc--auto_realm)
* [`auto_management_principal`](#-krb5--kdc--auto_management_principal)
* [`auto_generate_host_keytabs`](#-krb5--kdc--auto_generate_host_keytabs)

##### <a name="-krb5--kdc--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

An Array of hostnames or IP
addresses that are allowed into this system. Only used by the IPTables
settings.

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1', '::1'] })`

##### <a name="-krb5--kdc--config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

The path to the Puppet managed config files.

Default value: `'/var/kerberos/krb5kdc/kdc.conf.simp.d'`

##### <a name="-krb5--kdc--ldap"></a>`ldap`

Data type: `Boolean`

If set, configure the system to incorporate LDAP
components.
@note This presently does not set up the LDAP back-end for KRB5

Default value: `$krb5::ldap`

##### <a name="-krb5--kdc--firewall"></a>`firewall`

Data type: `Boolean`

If set, use the SIMP iptables module.

Default value: `$krb5::firewall`

##### <a name="-krb5--kdc--haveged"></a>`haveged`

Data type: `Boolean`

If set, enable the HAVEGE daemon for entropy

Default value: `$krb5::haveged`

##### <a name="-krb5--kdc--auto_initialize"></a>`auto_initialize`

Data type: `Boolean`

If set, create a default realm do all
necessary work to set up the environment for production.
@note This will simply use the system defaults. If you want something other
  than that, you'll need to call the `krb5::kdc::realm` define directly.

  If you select this, this *will* automatically initialize your Kerberos
  database and prepare your system to run.

Default value: `true`

##### <a name="-krb5--kdc--auto_realm"></a>`auto_realm`

Data type: `String`

If $auto_initialize is set, then use this string
as your default Kerberos Realm.

Default value: `$facts['networking']['domain']`

##### <a name="-krb5--kdc--auto_management_principal"></a>`auto_management_principal`

Data type: `String`

If $auto_initialize is set, then
use this string as the primary Kerberos principal name for the default Realm.

Default value: `'puppet_auto'`

##### <a name="-krb5--kdc--auto_generate_host_keytabs"></a>`auto_generate_host_keytabs`

Data type: `Boolean`

If set, create keytabs for all
hosts that Puppet currently knows about.
@note Host Principals are identified by having a 'host/<fqdn>' entry in the
  list of principals. Any host without one of these entries
  *will be ignored*.

  This is *not* dependent on `$auto_initialize`! You may want to toggle
  some of the parameters in the `krb5::kdc::auto_keytabs` class to tailor
  the generation.

  This capability expects a `${module_name}_files` module to be present in
  the environment's module path. It is **not** recommended that you place
  this module inside of the standard module path. Instead, the containing
  directory should be added to the `modulepath` directive of your
  `environment.conf`.
   @see https://docs.puppet.com/puppet/4.5/reference/config_file_environment.html
     With the `${module_name}_files` module, you should also have a section in
     your Puppet auth.conf that looks something like the following and is
     placed **before** the `path /file` stanza.

  @example auth.conf update
    # Restrict access to a directory that matches the hostname
    # Example: /environments/production/krb5_files/files/my.host.name.domain

    path ~ ^/file_(metadata|content)/modules/krb5_files/([^/]+)
    allow $2

Default value: `true`

### <a name="krb5--kdc--auto_keytabs"></a>`krb5::kdc::auto_keytabs`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

The keytabs will be collected in a directory that is, by default, located at
`/var/kerberos/krb5kdc/generated_keytabs`.

The target directory will have subdirectories created, one per
`host/fqdn@REALM` principal that match the `fqdn` of the host.

Each of those directories will have a krb5.keytab file created that contains
*all* discovered keytabs for the principal, *regardless of REALM*.

* **Note** If this is enabled on a Puppet server, and `$introspect` is `true`,
it will attempt to install the keytabs into the
`${environmentpath}/${environment}/site_files/${module_name}_files/files/keytabs`
directory.

It will also attempt to *automatically* create host keytabs for any hosts
in one of the following two directories:
  * `${environmentpath}/${environment}/keydist`
  * `${environmentpath}/${environment}/site_files/pki_files/files/keydist`

  @note For any of the above, if `$environmentpath` is empty, or does not
    exist, then `$confdir` will be substituted for
    `${environmentpath}/${environment}`

#### Parameters

The following parameters are available in the `krb5::kdc::auto_keytabs` class:

* [`introspect`](#-krb5--kdc--auto_keytabs--introspect)
* [`output_dir`](#-krb5--kdc--auto_keytabs--output_dir)
* [`all_known`](#-krb5--kdc--auto_keytabs--all_known)
* [`user`](#-krb5--kdc--auto_keytabs--user)
* [`group`](#-krb5--kdc--auto_keytabs--group)
* [`realms`](#-krb5--kdc--auto_keytabs--realms)
* [`global_services`](#-krb5--kdc--auto_keytabs--global_services)
* [`hosts`](#-krb5--kdc--auto_keytabs--hosts)
* [`purge`](#-krb5--kdc--auto_keytabs--purge)

##### <a name="-krb5--kdc--auto_keytabs--introspect"></a>`introspect`

Data type: `Boolean`

If set, attempt to discover, and create all
relevant keytabs from data on the Puppet server.
@note This has no effect if you aren't running on a Puppet server.

Default value: `true`

##### <a name="-krb5--kdc--auto_keytabs--output_dir"></a>`output_dir`

Data type: `Optional[Stdlib::Absolutepath]`

The directory into which to install the
keytabs.

Default value: `undef`

##### <a name="-krb5--kdc--auto_keytabs--all_known"></a>`all_known`

Data type: `Boolean`

If set, generate keytabs for any 'host/.*' entries
known to the KDC.

Default value: `false`

##### <a name="-krb5--kdc--auto_keytabs--user"></a>`user`

Data type: `String`

The user that should own the keytab files.

Default value: `'root'`

##### <a name="-krb5--kdc--auto_keytabs--group"></a>`group`

Data type: `String`

The group that should own the keytab files.

Default value: `'puppet'`

##### <a name="-krb5--kdc--auto_keytabs--realms"></a>`realms`

Data type: `String`

The REALMs into which the hosts should be added unless
otherwise specified in the `$hosts` Hash. Will be auto-upcased.

Default value: `simplib::lookup('krb5::kdc::auto_realm', { 'default_value' => $facts['networking']['domain'] })`

##### <a name="-krb5--kdc--auto_keytabs--global_services"></a>`global_services`

Data type: `Array[String]`

An Array of Kerberos services that
should be added to *all* hosts.

Default value: `[]`

##### <a name="-krb5--kdc--auto_keytabs--hosts"></a>`hosts`

Data type:

```puppet
Hash[String,
    Struct[{'ensure'             => Enum['absent','present'],
            Optional['realms']   => Array[String],
            Optional['services'] => Array[String]
    }]
  ]
```

A Hash of hosts for which keytabs should be
generated, and kept in the KDC by Puppet.
This is done as a Hash so that you don't end up with thousands of Puppet
resources in your catalog.
@note The Hash should be formatted as follows:
  {
    'fqdn' =>
      'ensure'   => ('absent'|'present') # Required
      'realms'   => ['REALM1', 'REALM2'] # Optional. Will be auto upcased.
      'services' => ['svc1','svc2']      # Optional
  }

@note This will be combined with the auto-generated hosts if $auto_generate
  is `true`

Default value: `{}`

##### <a name="-krb5--kdc--auto_keytabs--purge"></a>`purge`

Data type: `Boolean`

If set, purge any keytab directories for systems that
we don't know about.

Default value: `true`

### <a name="krb5--kdc--config"></a>`krb5::kdc::config`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

The variables used here can be found in kdc.conf(5).

Any variable *not* covered here can be managed using file resources.

#### Examples

##### Add Your Own Custom Config Snippet

```puppet
class my_krb5kdc {
  include 'krb5::kdc'

  file { "${krb5::kdc::config_dir}/my_snippet__custom":
    content => "My Custom Content"
  }

  Class['krb5::kdc'] -> Class['my_krb5kdc']
  Class['my_krb5kdc'] ~> Class['krb5::kdc::service']
}
```

#### Parameters

The following parameters are available in the `krb5::kdc::config` class:

* [`kdb5_password`](#-krb5--kdc--config--kdb5_password)
* [`kdc_ports`](#-krb5--kdc--config--kdc_ports)
* [`kdc_tcp_ports`](#-krb5--kdc--config--kdc_tcp_ports)

##### <a name="-krb5--kdc--config--kdb5_password"></a>`kdb5_password`

Data type: `String`

The password that should be used for auto-initializing the Principal
database

* If this password is changed, there will be **no** effect unless the
  password file is physically removed from the system

@note For safety, the Principal database will *not* be rebuilt unless it is
  physically absent from the system

Default value: `simplib::passgen('kdb5kdc', { 'length' => 1024 })`

##### <a name="-krb5--kdc--config--kdc_ports"></a>`kdc_ports`

Data type: `Array[Simplib::Port]`

The ``UDP`` ports on which the KDC should listen

Default value: `[88, 750]`

##### <a name="-krb5--kdc--config--kdc_tcp_ports"></a>`kdc_tcp_ports`

Data type: `Array[Simplib::Port]`

The ``TCP`` ports on which the KDC should listen

Default value: `[88, 750]`

### <a name="krb5--kdc--firewall"></a>`krb5::kdc::firewall`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

#### Parameters

The following parameters are available in the `krb5::kdc::firewall` class:

* [`kdc_ports`](#-krb5--kdc--firewall--kdc_ports)
* [`kdc_tcp_ports`](#-krb5--kdc--firewall--kdc_tcp_ports)
* [`trusted_nets`](#-krb5--kdc--firewall--trusted_nets)
* [`allow_kadmind`](#-krb5--kdc--firewall--allow_kadmind)
* [`kadmind_udp_ports`](#-krb5--kdc--firewall--kadmind_udp_ports)
* [`kadmind_tcp_ports`](#-krb5--kdc--firewall--kadmind_tcp_ports)

##### <a name="-krb5--kdc--firewall--kdc_ports"></a>`kdc_ports`

Data type: `Array[Simplib::Port]`

The ``UDP`` ports on which the KDC should listen

Default value: `$krb5::kdc::config::kdc_ports`

##### <a name="-krb5--kdc--firewall--kdc_tcp_ports"></a>`kdc_tcp_ports`

Data type: `Array[Simplib::Port]`

The ``TCP`` ports on which the KDC should listen

Default value: `$krb5::kdc::config::kdc_tcp_ports`

##### <a name="-krb5--kdc--firewall--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

Hostnames and/or IP addresses that are allowed into this system

* Only used by the IPTables settings

Default value: `$krb5::kdc::config::_trusted_nets`

##### <a name="-krb5--kdc--firewall--allow_kadmind"></a>`allow_kadmind`

Data type: `Boolean`

Allow remote connections to ``kadmind``

* You should probably always allow this

Default value: `true`

##### <a name="-krb5--kdc--firewall--kadmind_udp_ports"></a>`kadmind_udp_ports`

Data type: `Array[Simplib::Port]`

The ``UDP`` ports on which kadmind should listen

Default value: `[464]`

##### <a name="-krb5--kdc--firewall--kadmind_tcp_ports"></a>`kadmind_tcp_ports`

Data type: `Array[Simplib::Port]`

The ``TCP`` ports on which kadmind should listen

Default value: `[464, 749]`

### <a name="krb5--kdc--install"></a>`krb5::kdc::install`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

#### Parameters

The following parameters are available in the `krb5::kdc::install` class:

* [`ensure`](#-krb5--kdc--install--ensure)

##### <a name="-krb5--kdc--install--ensure"></a>`ensure`

Data type: `String`

The package state to ensure

* Accepts all valid options for the ``Package`` resource's ``ensure``
  parameter

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="krb5--kdc--selinux_hotfix"></a>`krb5::kdc::selinux_hotfix`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

The OS confinement of this class should be done elsewhere.

### <a name="krb5--kdc--service"></a>`krb5::kdc::service`

**NOTE: THIS IS A [PRIVATE](https://github.com/puppetlabs/puppetlabs-stdlib#assert_private) CLASS**

#### Parameters

The following parameters are available in the `krb5::kdc::service` class:

* [`ensure`](#-krb5--kdc--service--ensure)
* [`enable`](#-krb5--kdc--service--enable)

##### <a name="-krb5--kdc--service--ensure"></a>`ensure`

Data type: `String`

May be one of 'running' or 'stopped'.

Default value: `'running'`

##### <a name="-krb5--kdc--service--enable"></a>`enable`

Data type: `Boolean`

If true, enable the services at boot time.

Default value: `true`

### <a name="krb5--keytab"></a>`krb5::keytab`

Users should feel free to do what they like, but this will be consistent

#### Parameters

The following parameters are available in the `krb5::keytab` class:

* [`keytab_source`](#-krb5--keytab--keytab_source)
* [`owner`](#-krb5--keytab--owner)
* [`group`](#-krb5--keytab--group)
* [`mode`](#-krb5--keytab--mode)

##### <a name="-krb5--keytab--keytab_source"></a>`keytab_source`

Data type: `Any`

The `File` resource compatible source for the system keytab

Default value: `"puppet:///modules/krb5_files/keytabs/${facts['networking']['fqdn']}"`

##### <a name="-krb5--keytab--owner"></a>`owner`

Data type: `Any`

The keytab file owner

Default value: `'root'`

##### <a name="-krb5--keytab--group"></a>`group`

Data type: `Any`

The keytab file group

Default value: `'root'`

##### <a name="-krb5--keytab--mode"></a>`mode`

Data type: `Any`

The keytab file mode

Default value: `'0400'`

## Defined types

### <a name="krb5--kdc--realm"></a>`krb5::kdc::realm`

Note: The kdc.conf file is *fully managed* by Puppet

* **See also**
  * kdc.conf(5)
    * -> REALMS SECTION

#### Parameters

The following parameters are available in the `krb5::kdc::realm` defined type:

* [`initialize`](#-krb5--kdc--realm--initialize)
* [`auto_principal`](#-krb5--kdc--realm--auto_principal)
* [`trusted_nets`](#-krb5--kdc--realm--trusted_nets)
* [`acl_file`](#-krb5--kdc--realm--acl_file)
* [`admin_keytab`](#-krb5--kdc--realm--admin_keytab)
* [`database_name`](#-krb5--kdc--realm--database_name)
* [`default_principal_expiration`](#-krb5--kdc--realm--default_principal_expiration)
* [`default_principal_flags`](#-krb5--kdc--realm--default_principal_flags)
* [`dict_file`](#-krb5--kdc--realm--dict_file)
* [`kadmind_port`](#-krb5--kdc--realm--kadmind_port)
* [`kpasswd_port`](#-krb5--kdc--realm--kpasswd_port)
* [`key_stash_file`](#-krb5--kdc--realm--key_stash_file)
* [`kdc_ports`](#-krb5--kdc--realm--kdc_ports)
* [`kdc_tcp_ports`](#-krb5--kdc--realm--kdc_tcp_ports)
* [`master_key_name`](#-krb5--kdc--realm--master_key_name)
* [`master_key_type`](#-krb5--kdc--realm--master_key_type)
* [`max_life`](#-krb5--kdc--realm--max_life)
* [`max_renewable_life`](#-krb5--kdc--realm--max_renewable_life)
* [`iprop_enable`](#-krb5--kdc--realm--iprop_enable)
* [`iprop_master_ulogsize`](#-krb5--kdc--realm--iprop_master_ulogsize)
* [`iprop_slave_poll`](#-krb5--kdc--realm--iprop_slave_poll)
* [`supported_enctypes`](#-krb5--kdc--realm--supported_enctypes)
* [`reject_bad_transit`](#-krb5--kdc--realm--reject_bad_transit)
* [`config_dir`](#-krb5--kdc--realm--config_dir)
* [`ensure`](#-krb5--kdc--realm--ensure)
* [`firewall`](#-krb5--kdc--realm--firewall)

##### <a name="-krb5--kdc--realm--initialize"></a>`initialize`

Data type: `Boolean`

If set, auto-initialize the Realm. This will
add an initial Principal for this Realm.

Default value: `false`

##### <a name="-krb5--kdc--realm--auto_principal"></a>`auto_principal`

Data type: `String`

If ``$initialize`` is set, this principal will
be created as an administrative Principal on the Realm.

Default value: `'puppet_auto'`

##### <a name="-krb5--kdc--realm--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

networks to allow access into the KDC realm.

Default value:

```puppet
pick(
                                                                    getvar('krb5::kdc::trusted_nets'),
                                                                    simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1']})
                                                                  )
```

##### <a name="-krb5--kdc--realm--acl_file"></a>`acl_file`

Data type: `Stdlib::Absolutepath`

The path to the KDC realm ACL file.

Default value: `"/var/kerberos/krb5kdc/kadm5_${name}.acl"`

##### <a name="-krb5--kdc--realm--admin_keytab"></a>`admin_keytab`

Data type: `Stdlib::Absolutepath`

The path to the KDC realm keytab.

Default value: `"/var/kerberos/krb5kdc/kadm5_${name}.keytab"`

##### <a name="-krb5--kdc--realm--database_name"></a>`database_name`

Data type: `Optional[String]`

The path to the KDC realm database.

Default value: `undef`

##### <a name="-krb5--kdc--realm--default_principal_expiration"></a>`default_principal_expiration`

Data type: `Optional[String]`

The Absolute Time for
expiring the principal expiration date for this realm.
@see http://web.mit.edu/kerberos/krb5-devel/doc/basic/date_format.html#abstime

Default value: `undef`

##### <a name="-krb5--kdc--realm--default_principal_flags"></a>`default_principal_flags`

Data type: `Array[String]`

An array following the
format prescribed in the man page. The absence of a '-' in front of the
entry implies that a '+' will be added.

Default value: `[]`

##### <a name="-krb5--kdc--realm--dict_file"></a>`dict_file`

Data type: `Stdlib::Absolutepath`

The path to the dictionary file of strings
that are not allowed as passwords.

Default value: `'/usr/share/dict/words'`

##### <a name="-krb5--kdc--realm--kadmind_port"></a>`kadmind_port`

Data type: `Optional[Simplib::Port]`

The port on which kadmind should listen.

Default value: `undef`

##### <a name="-krb5--kdc--realm--kpasswd_port"></a>`kpasswd_port`

Data type: `Optional[Simplib::Port]`

The port on which kpasswd should listen.

Default value: `undef`

##### <a name="-krb5--kdc--realm--key_stash_file"></a>`key_stash_file`

Data type: `Optional[Stdlib::Absolutepath]`

The path to the KDC realm master key.

Default value: `undef`

##### <a name="-krb5--kdc--realm--kdc_ports"></a>`kdc_ports`

Data type: `Array[Simplib::Port]`

UDP ports upon which the KDC should listen.

Default value: `[]`

##### <a name="-krb5--kdc--realm--kdc_tcp_ports"></a>`kdc_tcp_ports`

Data type: `Array[Simplib::Port]`

TCP ports upon which the KDC should listen.

Default value: `[]`

##### <a name="-krb5--kdc--realm--master_key_name"></a>`master_key_name`

Data type: `Optional[String]`

The principal associated with the master key.

Default value: `undef`

##### <a name="-krb5--kdc--realm--master_key_type"></a>`master_key_type`

Data type: `String`

The master key's key type.

Default value: `'aes256-cts'`

##### <a name="-krb5--kdc--realm--max_life"></a>`max_life`

Data type: `Optional[String]`

The maximum time period for which a ticket may be valid.
Should be a valid krb5 Time Duration string.
@see http://web.mit.edu/kerberos/krb5-1.13/doc/basic/date_format.html#duration

Default value: `undef`

##### <a name="-krb5--kdc--realm--max_renewable_life"></a>`max_renewable_life`

Data type: `Optional[String]`

The maximum time period during which
a valid ticket may be renewed.  Should be a valid krb5 Time Duration string.

Default value: `undef`

##### <a name="-krb5--kdc--realm--iprop_enable"></a>`iprop_enable`

Data type: `Optional[Boolean]`

Whether incremental database propogation is enabled.

Default value: `undef`

##### <a name="-krb5--kdc--realm--iprop_master_ulogsize"></a>`iprop_master_ulogsize`

Data type: `Optional[Integer]`

The maximum number of log entries for
incremental propogation.

Default value: `undef`

##### <a name="-krb5--kdc--realm--iprop_slave_poll"></a>`iprop_slave_poll`

Data type: `Optional[String]`

How often the KDC polls for new updates
from the master.

Default value: `undef`

##### <a name="-krb5--kdc--realm--supported_enctypes"></a>`supported_enctypes`

Data type: `Array[String]`

The default key/salt combinations for this realm.

Default value: `[ 'aes256-cts:normal', 'aes128-cts:normal' ]`

##### <a name="-krb5--kdc--realm--reject_bad_transit"></a>`reject_bad_transit`

Data type: `Optional[Boolean]`

Whether to check the list of transited
realms for cross-realm tickets.

Default value: `undef`

##### <a name="-krb5--kdc--realm--config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

The path to the Puppet managed config files.

Default value: `simplib::lookup('krb5::kdc::config_dir', { 'default_value' => '/var/kerberos/krb5kdc/kdc.conf.simp.d' })`

##### <a name="-krb5--kdc--realm--ensure"></a>`ensure`

Data type: `String`

Whether to set or clear the key.
Valid values are 'present' and 'absent'. Setting anything besides 'absent'
will default to 'present'.

Default value: `'present'`

##### <a name="-krb5--kdc--realm--firewall"></a>`firewall`

Data type: `Boolean`

Whether to add appropriate iptables rules for KDC

Default value: `simplib::lookup('krb5::kdc::firewall', { 'default_value' => false })`

### <a name="krb5--setting"></a>`krb5::setting`

Sections with nested sub-sections or allowed repeated keys have their own
specialized defines.

* **See also**
  * krb5.conf(5)

#### Parameters

The following parameters are available in the `krb5::setting` defined type:

* [`value`](#-krb5--setting--value)
* [`target`](#-krb5--setting--target)
* [`ensure`](#-krb5--setting--ensure)
* [`filemode`](#-krb5--setting--filemode)
* [`seltype`](#-krb5--setting--seltype)

##### <a name="-krb5--setting--value"></a>`value`

Data type: `Scalar`

The number/string/boolean that should be used to set the
designated value. This will *not* be processed so make sure that it's
what you want to output to the system.

##### <a name="-krb5--setting--target"></a>`target`

Data type: `Stdlib::Absolutepath`

The target *directory* to which to add setting files.

Default value: `pick(getvar('krb5::config::config_dir'), '/etc/krb5.conf.d')`

##### <a name="-krb5--setting--ensure"></a>`ensure`

Data type: `String`

Whether to set or clear the key. Valid values are
'present' and 'absent'.  Setting anything besides 'absent' will default to
'present'.

Default value: `'present'`

##### <a name="-krb5--setting--filemode"></a>`filemode`

Data type: `String`

The File mode (per the Puppet File resource) that
should be set on the settings files.

Default value: `'0644'`

##### <a name="-krb5--setting--seltype"></a>`seltype`

Data type: `String`

The SELinux Type to which to set the file that holds
the setting.

Default value: `'krb5_conf_t'`

### <a name="krb5--setting--domain_realm"></a>`krb5::setting::domain_realm`

It was specifically created so that you could pass in your domains as a name
array and then your realm as a value.

* **See also**
  * krb5.conf(5)

#### Parameters

The following parameters are available in the `krb5::setting::domain_realm` defined type:

* [`ensure`](#-krb5--setting--domain_realm--ensure)
* [`realm`](#-krb5--setting--domain_realm--realm)
* [`target`](#-krb5--setting--domain_realm--target)

##### <a name="-krb5--setting--domain_realm--ensure"></a>`ensure`

Data type: `String`

Whether to set or clear the key. Valid values are
'present' and 'absent'.  Setting anything besides 'absent' will default to
'present'.

Default value: `'present'`

##### <a name="-krb5--setting--domain_realm--realm"></a>`realm`

Data type: `String`

The realm to which to map your domain.

##### <a name="-krb5--setting--domain_realm--target"></a>`target`

Data type: `Stdlib::Absolutepath`

The target *directory* to which to add setting files.

Default value: `pick(getvar('krb5::config::config_dir'), '/etc/krb5.conf.d')`

### <a name="krb5--setting--realm"></a>`krb5::setting::realm`

Allows you to add a realm to the ``[realms]`` section of ``/etc/krb5.conf``.

* **See also**
  * krb5.conf(5)
    * -> REALMS SECTION

#### Parameters

The following parameters are available in the `krb5::setting::realm` defined type:

* [`admin_server`](#-krb5--setting--realm--admin_server)
* [`kdc`](#-krb5--setting--realm--kdc)
* [`default_domain`](#-krb5--setting--realm--default_domain)
* [`v4_instance_convert`](#-krb5--setting--realm--v4_instance_convert)
* [`v4_realm`](#-krb5--setting--realm--v4_realm)
* [`auth_to_local_names`](#-krb5--setting--realm--auth_to_local_names)
* [`auth_to_local`](#-krb5--setting--realm--auth_to_local)
* [`target`](#-krb5--setting--realm--target)
* [`owner`](#-krb5--setting--realm--owner)
* [`group`](#-krb5--setting--realm--group)
* [`mode`](#-krb5--setting--realm--mode)

##### <a name="-krb5--setting--realm--admin_server"></a>`admin_server`

Data type: `Simplib::Host`

The host where the admin server is running.

##### <a name="-krb5--setting--realm--kdc"></a>`kdc`

Data type: `Optional[Simplib::Host]`

The host where the KDC is running.

Default value: `undef`

##### <a name="-krb5--setting--realm--default_domain"></a>`default_domain`

Data type: `Optional[String]`

The default domain in which hosts are assumed
to be present.

Default value: `undef`

##### <a name="-krb5--setting--realm--v4_instance_convert"></a>`v4_instance_convert`

Data type: `Hash[String,String]`

A hash of 'tag name' to 'tag value'
mappings for default domain mapping translations.

Default value: `{}`

##### <a name="-krb5--setting--realm--v4_realm"></a>`v4_realm`

Data type: `Optional[String]`

The v4 realm to be used when talking to legacy
systems.

Default value: `undef`

##### <a name="-krb5--setting--realm--auth_to_local_names"></a>`auth_to_local_names`

Data type: `Hash[String,String]`

A hash of 'principal names' to 'local user
names' per the man page.

Default value: `{}`

##### <a name="-krb5--setting--realm--auth_to_local"></a>`auth_to_local`

Data type: `Optional[String]`

A general rule for mapping to local user names.
The following values are allowed:
  DB:<filename>
  RULE:<exp>
  DEFAULT

Default value: `undef`

##### <a name="-krb5--setting--realm--target"></a>`target`

Data type: `Stdlib::Absolutepath`

The path to the Puppet managed config files.

Default value: `pick(getvar('krb5::config::config_dir'), '/etc/krb5.conf.d')`

##### <a name="-krb5--setting--realm--owner"></a>`owner`

Data type: `String`



Default value: `'root'`

##### <a name="-krb5--setting--realm--group"></a>`group`

Data type: `String`



Default value: `'root'`

##### <a name="-krb5--setting--realm--mode"></a>`mode`

Data type: `String`



Default value: `'0644'`

## Resource types

### <a name="krb5_acl"></a>`krb5_acl`

Manages krb5 kadmind ACL entries per kadmind(8). When removing an
entry, you can specify a regex for the operation_target and all
associated entries will be removed.

#### Properties

The following properties are available in the `krb5_acl` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `operation_mask`

Valid values: `%r{^([admcilpADMCILP]+|[x*])$}`

The operation mask per kadmind(8). Be aware that lower case activates a mask and upper case deactivates it

#### Parameters

The following parameters are available in the `krb5_acl` type.

* [`name`](#-krb5_acl--name)
* [`operation_target`](#-krb5_acl--operation_target)
* [`principal`](#-krb5_acl--principal)
* [`provider`](#-krb5_acl--provider)
* [`target`](#-krb5_acl--target)

##### <a name="-krb5_acl--name"></a>`name`

namevar

A required, but meaningless, name

##### <a name="-krb5_acl--operation_target"></a>`operation_target`

An optional partially, or fully, qualified Kerberos 5 principal
name upon which 'principal' is allowed to operate. If this is
specified, the 'principal', 'operation_mask', and 'ensure' options
will be restricted. This must be specified as a ruby regex without
'/' in the case of ensure => 'absent'.

Default value: `undef`

##### <a name="-krb5_acl--principal"></a>`principal`

The partially, or fully, qualified Kerberos 5 principal name. This
is what must appear as the usual 'name' of the resource.

##### <a name="-krb5_acl--provider"></a>`provider`

The specific backend to use for this `krb5_acl` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="-krb5_acl--target"></a>`target`

The ACL file upon which to operate

Default value: `/var/kerberos/krb5kdc/kadm5.acl`

### <a name="krb5kdc_auto_keytabs"></a>`krb5kdc_auto_keytabs`

Auto-generates principals and keytabs on a functional KDC and outputs the
keytabs to a directory of the user's choosing.

Can optionally take a hash of hosts, with associated principal metadata,
to be created on the KDC. Will warn if you are attempting to add a host
that does not have a valid REALM.

#### Properties

The following properties are available in the `krb5kdc_auto_keytabs` type.

##### `ensure`

Valid values: `present`, `generated`, `absent`

The state to enforce on the resource

Default value: `present`

#### Parameters

The following parameters are available in the `krb5kdc_auto_keytabs` type.

* [`all_known`](#-krb5kdc_auto_keytabs--all_known)
* [`global_services`](#-krb5kdc_auto_keytabs--global_services)
* [`group`](#-krb5kdc_auto_keytabs--group)
* [`hosts`](#-krb5kdc_auto_keytabs--hosts)
* [`introspect`](#-krb5kdc_auto_keytabs--introspect)
* [`name`](#-krb5kdc_auto_keytabs--name)
* [`provider`](#-krb5kdc_auto_keytabs--provider)
* [`purge`](#-krb5kdc_auto_keytabs--purge)
* [`realms`](#-krb5kdc_auto_keytabs--realms)
* [`user`](#-krb5kdc_auto_keytabs--user)

##### <a name="-krb5kdc_auto_keytabs--all_known"></a>`all_known`

Valid values: `true`, `false`, `yes`, `no`

Generate keytabs for any 'host/.*' entires known to the KDC.

Default value: `false`

##### <a name="-krb5kdc_auto_keytabs--global_services"></a>`global_services`

The global services that should be applied to *every* auto-generated principal

##### <a name="-krb5kdc_auto_keytabs--group"></a>`group`

The group that should own the generated keytabs, defaults to
'#{Puppet[:group]}' when installing into a Puppet Environment and 'root'
otherwise.

Default value: `group`

##### <a name="-krb5kdc_auto_keytabs--hosts"></a>`hosts`

A Hash of hosts that should be managed in the KDC.

The Hash format should be as follows:

{
  'fqdn' => {
    'ensure'   => ('absent' | 'present') # Required
    'realms'   => ['REALM1', 'REALM2']   # Optional. Will be auto-upcased
    'services' => ['svc1','svc2']        # Optional
  }
}

If '$global_services' is set, it will be added to the list of services for each host here.

##### <a name="-krb5kdc_auto_keytabs--introspect"></a>`introspect`

Valid values: `true`, `false`, `yes`, `no`

Attempt to discover, and create, all relevant keytabs from data on the
Puppet server.

This *will* create host principals for discovered entities if they do not
exist already!

This takes a best guess from the SIMP default PKI key locations:
  * `${environmentpath}/${environment}/keydist`
  * `/var/simp/environments/${environment}/site_files/pki_files/files/keydist`

If `$environmentpath` is not set, then `$confdir` will be substituted for
`${environmentpath}/${environment}`

Default value: `true`

##### <a name="-krb5kdc_auto_keytabs--name"></a>`name`

namevar

The output directory to which to write the keytabs

If '__default__' will be set to either
`/var/simp/environments/${environment}/site_files/krb5_files/files/keytabs` or
`/var/kerberos/krb5kdc/generated_keytabs` depending on which target path
exists.

##### <a name="-krb5kdc_auto_keytabs--provider"></a>`provider`

The specific backend to use for this `krb5kdc_auto_keytabs` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

##### <a name="-krb5kdc_auto_keytabs--purge"></a>`purge`

Valid values: `true`, `false`, `yes`, `no`

Remove all unmanaged keytabs from the '$name' directory

Default value: `true`

##### <a name="-krb5kdc_auto_keytabs--realms"></a>`realms`

The realms under which the hosts should be generated

Default value: `Facter.value(:networking)['domain']`

##### <a name="-krb5kdc_auto_keytabs--user"></a>`user`

The user that should own the generated keytabs, defaults to
'#{Puppet[:user]}' when installing into a Puppet Environment and 'root'
otherwise.

Default value: `root`

## Functions

### <a name="krb5--munge_conf_filename"></a>`krb5::munge_conf_filename`

Type: Ruby 4.x API

Returns a string that is safe to use as a filename for including in
 krb5 configuration files.

#### `krb5::munge_conf_filename(String $name)`

Returns a string that is safe to use as a filename for including in
 krb5 configuration files.

Returns: `Any` String transformed filename

##### `name`

Data type: `String`

String to be converted to a k4b6 configuration filename

### <a name="krb5--validate_time_duration"></a>`krb5::validate_time_duration`

Type: Ruby 4.x API

Validates that the passed string is a valid krb5 time duration per
http://web.mit.edu/kerberos/krb5-1.13/doc/basic/date_format.html#duration.

#### `krb5::validate_time_duration(String $time_duration)`

Validates that the passed string is a valid krb5 time duration per
http://web.mit.edu/kerberos/krb5-1.13/doc/basic/date_format.html#duration.

Returns: `Undef`

##### `time_duration`

Data type: `String`

Time duration string to be validated

